==> huaweicloudsdkcdn-3.1.65-py2.py3-none-any.whl: huaweicloudsdkcdn/v1/model/compress_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class CompressRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'compress_switch': 'int'
    }

    attribute_map = {
        'compress_switch': 'compress_switch'
    }

    def __init__(self, compress_switch=None):
        """CompressRequest

        The model defined in huaweicloud sdk

        :param compress_switch: GZIP压缩开关。0关闭。1打开。
        :type compress_switch: int
        """
        
        

        self._compress_switch = None
        self.discriminator = None

        if compress_switch is not None:
            self.compress_switch = compress_switch

    @property
    def compress_switch(self):
        """Gets the compress_switch of this CompressRequest.

        GZIP压缩开关。0关闭。1打开。

        :return: The compress_switch of this CompressRequest.
        :rtype: int
        """
        return self._compress_switch

    @compress_switch.setter
    def compress_switch(self, compress_switch):
        """Sets the compress_switch of this CompressRequest.

        GZIP压缩开关。0关闭。1打开。

        :param compress_switch: The compress_switch of this CompressRequest.
        :type compress_switch: int
        """
        self._compress_switch = compress_switch

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CompressRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkcdn-3.1.158-py2.py3-none-any.whl: huaweicloudsdkcdn/v1/model/compress_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class CompressRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'compress_switch': 'int'
    }

    attribute_map = {
        'compress_switch': 'compress_switch'
    }

    def __init__(self, compress_switch=None):
        r"""CompressRequest

        The model defined in huaweicloud sdk

        :param compress_switch: GZIP压缩开关。0关闭。1打开。
        :type compress_switch: int
        """
        
        

        self._compress_switch = None
        self.discriminator = None

        if compress_switch is not None:
            self.compress_switch = compress_switch

    @property
    def compress_switch(self):
        r"""Gets the compress_switch of this CompressRequest.

        GZIP压缩开关。0关闭。1打开。

        :return: The compress_switch of this CompressRequest.
        :rtype: int
        """
        return self._compress_switch

    @compress_switch.setter
    def compress_switch(self, compress_switch):
        r"""Sets the compress_switch of this CompressRequest.

        GZIP压缩开关。0关闭。1打开。

        :param compress_switch: The compress_switch of this CompressRequest.
        :type compress_switch: int
        """
        self._compress_switch = compress_switch

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CompressRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
